@@ -207,7 +207,56 @@ class NEUSetter:
         print(f"{Fore.light_sea_green}Done{Fore.light_yellow} Cleaning PairCollection's{Style.reset}")
 
         #scan through PairCollection table and check each barcode for an entry in Entry and if not exists, prompt to create it/skip it/delete it, perform said action, and remove PairCollection with corresponding Barcode
-                
+    
+    def delete(self):
+        while True:
+            try:
+                if self.code in [None,]:
+                    barcode=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"[DELETE] {Fore.light_green}Barcode|{Fore.turquoise_4}Code|{Fore.light_magenta}Name{Fore.light_yellow}:",helpText="what are you looking for?",data="string")
+                    if barcode in ['d',None]:
+                        return
+                else:
+                    barcode=self.code
+                with Session(ENGINE) as session:
+                    query=session.query(Entry).filter(or_(
+                        Entry.Barcode==barcode,
+                        Entry.Code==barcode,
+                        Entry.Barcode.icontains(barcode),
+                        Entry.Code.icontains(barcode),
+                        Entry.Name.icontains(barcode)
+                        ))
+                    results=query.all()
+                    ct=len(results)
+                    if ct == 0:
+                        print("Nothing Found")
+                        if self.code in [None,]:
+                            continue
+                        else:
+                            return
+
+                    for num,entry in enumerate(results):
+                        msg=f'{Fore.light_green}{num}/{Fore.light_yellow}{num+1} of {Fore.light_red}{ct} -> {entry.seeShort()}'
+                        print(msg)
+                    whiches=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"[DELETE]which {Fore.light_green}index{Fore.light_yellow}?: ",helpText=f"{Fore.light_steel_blue}which index {Fore.light_yellow}number in light yellow{Style.reset}",data="list")
+                    if whiches is None:
+                        return
+                    elif whiches in [[],'d']:
+                        return
+                    for which in whiches:
+                        try:
+                            index=int(which)
+                            try:
+                                session.delete(results[index])
+                                session.commit()
+                            except Exception as e:
+                                print(e)
+                                session.rollback()
+                        except Exception as e:
+                            print(e)
+                    break
+            except Exception as e:
+                print(e)
+                return
 
     def setFieldByName(self,fname):
         fnames=[]
